# CNC Machining Overview

The CNC (Computer Numerical Control) machine used in this lab is a large-format router capable of cutting full-sized wooden sheets using a 6mm cutting tool. It operates through instructions received from a computer, translating CAD designs into toolpaths that direct the cutting head’s movement, speed, and depth. These toolpaths ensure precision and repeatability by controlling the spindle’s rotation (RPM), feed rate (inches per minute), and cut depth.

**Functionality Summary:**
- Receives commands from a computer.
- Follows toolpaths derived from CAD designs.
- Cuts materials with controlled speed and depth.
- Used for manufacturing wooden structures, furniture, and fit-based assemblies.

![Insert image of CNC machine here](insert_image_path_here)

---

#### Video - Full Explanation

The video below showcases how the system works with explanation.

---

#### Safety Requirements

Strict safety protocols must be followed when operating the CNC machine:

- **Eye Protection:** Safety glasses must be worn to shield eyes from debris.
- **Face Mask:** Use a face mask to prevent inhalation of fine dust particles.
- **Clothing:** Avoid loose garments, jewelry, or accessories that may get caught.
- **Work Area Inspection:** Check the machine and all tools before starting.
- **Clean Environment:** Keep the machine and surroundings clear of clutter before and after use.
- **Hearing Protection:** Strongly recommended, though not always provided.
- **Emergency Stop:** Be aware of the emergency stop button location.
- **Operational Distance:** Stay a safe distance from the machine while in use.
- **Handling Materials:** Never attempt to remove or adjust material while the machine is active.
- **Supervision:** Machine operation must always be monitored during cutting.

![Insert image of safety gear or workspace here](insert_image_path_here)

---

#### Design Requirements

When designing for CNC cutting:
- Maintain at least **20 mm gap** between each design part.
- Keep designs at least **30 mm away** from each sheet corner.
- Ensure holes in your design are **larger than the drill bit’s diameter** so they can be cut cleanly.
- Select drill bits **larger than your material’s thickness** for full cuts.
- Export files in **DXF format** for compatibility.
- Double-check that the design size suits the tool (e.g., drill bit not larger than the smallest detail).

---

#### Debris Management

The CNC machine includes a built-in vacuum system that removes debris generated during cutting. This ensures:
- Cleaner work environment.
- Improved visibility and safety.
- Better cut accuracy and finish.

---

#### Importance of Dogbones

Due to the round shape of the cutting tool, internal corners in wooden joints are not naturally square. Adding **dogbone fillets** to these corners allows parts to fit tightly and accurately in press-fit constructions.

---

#### Material Alignment and Sacrificial Sheet

Proper material positioning is crucial to cut accuracy. A **sacrificial sheet** is placed under the cutting material to:
- Prevent damage to the CNC bed.
- Allow cuts to go slightly deeper than the material thickness.
- Help hold the material in place with screws.

**Tips for Alignment:**
- Max sheet size: 2440 x 1220 x 12 mm (L x W x T).
- If the sheet is curved, place the concave side down.
- Secure with bolts placed within 20 mm of the corners and across the center.

---

#### Materials Used

Two materials are commonly available:

- **MDF (Medium-Density Fiberboard):**
  - Smooth surface.
  - Easy to machine.
  - Less durable.

- **Plywood:**
  - Layered structure.
  - Stronger and more resilient.
  - Harder to cut cleanly.

Cutting tests were conducted using MDF, optimizing speed and feed rate for best results.

---

#### Machine Alignment

Machine calibration is required before each cutting job. For this CNC machine:

- **Z-axis calibration** is automated.
- A metal plate and wire clip are used. Once the drill touches the plate, an electrical signal finalizes the zero position.
- Regular checks are needed for worn parts and tool integrity.

---

#### Drill Bit Selection Guidance

Choosing the right drill bit (end mill) is essential for clean, efficient cuts and depends on your material and the operation:

- **Upcut Bit:**
  - Best for fast chip removal.
  - Leaves a rough top surface but clean bottom.
  - Good for deeper cuts.

- **Downcut Bit:**
  - Pushes fibers down.
  - Leaves a smooth top surface.
  - Good for thinner materials or laminated surfaces.

- **Compression Bit:**
  - Combines upcut and downcut features.
  - Smooth on both sides.
  - Ideal for plywood or double-sided finish materials.

- **Bit Diameter:**
  - 6mm (default) is versatile for general cutting.
  - Use smaller bits (e.g., 3mm) for detailed work.
  - Larger bits (e.g., 12mm) for faster rough cuts on thicker materials.

---

#### Speed & Feed

Proper speed and feed rate settings are critical for effective cuts:

- **Speed (RPM):** Determines how fast the tool rotates.
- **Feed Rate (in/min):** Determines how fast the tool moves across the material.

For MDF using a 6mm tool:
- Optimal Speed: 8000 RPM
- Feed Rate: 80 in/min (can vary based on tool condition and material)

Monitor chip formation and surface quality during tests to fine-tune settings.

---

#### Tips to Reduce Material Waste

- **Group Parts Efficiently:** Nest your parts close together in CAD to use the least amount of space. [20mm space]
- **Use Off-Cuts:** Save and reuse unused areas of the sheet for future small projects or test cuts.
- **Add Labels:** Include engraved labels to organize parts and reduce re-cuts.
- **Test on Scrap:** Run test cuts on scrap wood or corners before running the full job.
- **Minimize Tabs:** Use just enough tabs to hold parts in place without excess material.

---

#### CNC Cutting Process

This section outlines the full workflow for using the CNC machine, from preparation to final cutting.

---

#### 1. Preparation

- Remove debris and previous sheets using a vacuum.
- Unscrew and clear the CNC bed.
- Place the new sheet (MDF or Plywood).
- Adjust the sheet if bent; curve should face up with the middle touching the base.
- Fasten using screws ~30 mm from the edges and along the center.

![Insert preparation image here](insert_image_path_here)

---

#### 2. VCarve PRO Setup

- Export the design as a **DXF** file.
- Send the file to: `fablabbh.share@gmail.com`
- Open the file in **VCarve PRO**.
- Add a **30 mm offset** around the perimeter to avoid bolts.
- Use **Dogbone Fillet** tool (match radius to tool size, e.g., 3 mm for 6 mm bit).
  
![Insert VCarve screenshot here](insert_image_path_here)

---

#### Assigning Cut/Pocket

Select the lines or shapes to define what will be cut or pocketed, then apply the relevant toolpath operation (profile/pocket).

---

#### 3. Toolpaths: Cut
  - Cuts along the outer or inner edge of a part.
  - Defines the final shape by following the contour
- Choose **Profile Toolpath**.
- Set:
  - **Start Depth:** 0 mm
  - **Cut Depth:** 13 mm (12 mm material + 1 mm into sacrificial sheet)
- Tool Settings (6 mm bit):
  - Spindle Speed: 8000 RPM
  - Feed Rate: 80 in/min
  - Plunge Rate: 15 in/min
- Specify the Number of Passes:
  - Press "Edit Passes"
    - Number of Passes: 2
      - First Pass Depth: 6.5mm
      - Second Pass Depth: 13mm
- Specify Machine Vectors:
  - Select **Outside/Right** for vector machining to preserve size.
  - Select **Inside/Left** for cutting internal shapes or holes.
  - Select **On** for trimming directly along the vector line.
- Click **Calculate**, then read the warnings, if it is within your expectations click **OK** to confirm.

---

#### 4. Toolpaths: Pocket
  - Used to hollow out an internal region.
  - Useful for engravings or fitting one piece into another.
- Choose **Pocket Toolpath**.
- Set:
  - **Start Depth:** 0.0 mm
  - **Cut Depth:** 2.0 mm
- Recheck "Tool" Parameters:
  - Press "Edit": 
    - Geometry:
      - Diameter: 6mm
    - Cutting Parameters:
      - Pass Depth: 6mm
      - Stepover: 4.002mm || 66.7%
    - Feeds and Speeds:
      - Spindle Speed: 8000 RPM
      - Feed Rate: 80 in/min
      - Plunge Rate: 15 in/min
    - Tool Number: 1
    - Press "OK"

#### 5. Tabs
  - Small, uncut sections to keep parts attached to the sheet.
  - Prevents shifting or flying parts.
  - Size: Usually 3 mm wide and 2 mm high.
  - Automatically added in the Toolpath menu.
  - Best used manually to avoid tabs at the edges. 

---

#### 6. Preview Toolpaths  
- Go to the **3D View** tab.  
- Click:
  - **Reset Preview**  
  - **Preview Visible Toolpaths**  
- If the toolpath appears erratic, the design may be **too small for the selected drill bit**.  
- Fix it by:
  - Returning to the **project tab**  
  - Resizing the design (drag from its edge)  
  - Or adjusting in your design software and re-exporting  
- In the **Toolpath List**:
  - Double-click **"Pocket 1"**  
  - Click **Calculate**  
- Repeat the adjustment if the toolpath still behaves erratically.

#### 7. Changing the Drill Bit  
- Turn off the CNC machine using the key (located at the bottom right) and remove it.  
- Use two wrenches to loosen the collet assembly.  
  - Hold both wrenches in one hand to stabilize, and twist the lower wrench to loosen the collet nut.  
- Remove the collet and clean both the collet and nut for a secure fit.  
- Reinsert the collet into its housing.  
- Insert the new drill bit, leaving ~20 mm (or two fingers) exposed for cutting clearance.  
- Tighten the collet assembly firmly using both wrenches.  
- Reinsert the key, power on the machine, and re-calibrate the Z-axis.

#### 8. ShopBot 3 Setup

- Open **ShopBot 3** software.
- Load the toolpath file (.sbp).
- Move the drill head to desired origin (corner of the sheet).
- Set:
  - **X = 0**
  - **Y = 0**
- Run Z-axis calibration.

---

#### 9. Z-Axis Calibration

- Clip the wire to the collet nut or the spindle body of the CNC machine.
- Place the **metal calibration plate** on the surface of the sheet.
- Run the **Z-zeroing command** (machine lowers bit to touch the plate).
- System detects contact and sets Z = 0.
-  After calibration, remove the clip and plate, then return them to their original location with the clip still attached to the plate. This ensures smooth CNC operation.

---

#### 10. Start Machining

- Click **Start** to begin the operation.
- Monitor the machine continuously.
- Do not touch or adjust material until the machine is fully stopped.
- After cutting completes, remove remaining debris.

![Insert cutting process image here](insert_image_path_here)

---